@@ -222,23 +222,22 @@ class CB:
         def cb(response):
             CB._status(response, allow_404=allow_404)
             if response.code == 404:
-                return response.headers['X-Consul-Index'], None
-
-            data = json.loads(response.body)
-
-            if decode:
-                for item in data:
-                    if item.get(decode) is not None:
-                        item[decode] = base64.b64decode(item[decode])
-            if is_id:
-                data = data['ID']
-            if one:
-                if data == []:
-                    data = None
-                if data is not None:
-                    data = data[0]
-            if map:
-                data = map(data)
+                data = None
+            else:
+                data = json.loads(response.body)
+                if decode:
+                    for item in data:
+                        if item.get(decode) is not None:
+                            item[decode] = base64.b64decode(item[decode])
+                if is_id:
+                    data = data['ID']
+                if one:
+                    if data == []:
+                        data = None
+                    if data is not None:
+                        data = data[0]
+                if map:
+                    data = map(data)
             if index:
                 return response.headers['X-Consul-Index'], data
             return data
@@ -1169,7 +1168,7 @@ class Consul:
                     params.append(('token', token))
 
                 return self.agent.http.put(
-                    CB.bool(),
+                    CB.json(),
                     '/v1/agent/connect/authorize',
                     params=params,
                     data=json.dumps(payload))
@@ -1190,7 +1189,7 @@ class Consul:
                         params.append(('token', token))
 
                     return self.agent.http.get(
-                        CB.bool(),
+                        CB.json(),
                         '/v1/agent/connect/ca/leaf/%s' % service,
                         params=params)
 
@@ -2617,7 +2616,7 @@ class Consul:
                     params.append(('token', token))
 
                 return self.agent.http.get(
-                    CB.bool(),
+                    CB.json(),
                     '/v1/connect/ca/roots',
                     params=params)
 
@@ -2628,6 +2627,6 @@ class Consul:
                     params.append(('token', token))
 
                 return self.agent.http.get(
-                    CB.bool(),
+                    CB.json(),
                     '/v1/connect/ca/configuration',
                     params=params)
